@@ -44,24 +44,12 @@
 
 extern p11_mutex_t p11_library_mutex;
 
+extern unsigned int p11_forkid;
+
 #define       p11_lock()                   p11_mutex_lock (&p11_library_mutex);
 
 #define       p11_unlock()                 p11_mutex_unlock (&p11_library_mutex);
 
-void          p11_message                  (const char* msg,
-                                            ...) GNUC_PRINTF (1, 2);
-
-void          p11_message_store            (const char* msg,
-                                            size_t length);
-
-const char *  p11_message_last             (void);
-
-void          p11_message_clear            (void);
-
-void          p11_message_quiet            (void);
-
-void          p11_message_loud             (void);
-
 #ifdef OS_WIN32
 
 /* No implementation, because done by DllMain */
